Balancing
---------

**Header:** ``mockturtle/algorithms/balancing.hpp``

Parameters and Statistics
~~~~~~~~~~~~~~~~~~~~~~~~~

.. doxygenstruct:: mockturtle::balancing_params
   :members:

.. doxygenstruct:: mockturtle::balancing_stats
   :members:

Algorithm
~~~~~~~~~

.. doxygenfunction:: mockturtle::sop_balancing

.. doxygenfunction:: mockturtle::esop_balancing

.. doxygenfunction:: mockturtle::balancing

Rebalancing engines
~~~~~~~~~~~~~~~~~~~

**Header:** ``mockturtle/algorithms/balancing/sop_balancing.hpp``

.. doxygenstruct:: mockturtle::sop_rebalancing

**Header:** ``mockturtle/algorithms/balancing/esop_balancing.hpp``

.. doxygenstruct:: mockturtle::esop_rebalancing
